#
# spec file for package dropwatch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dropwatch
Version:        1.5.4
Release:        4.1
Summary:        Kernel dropped packet monitor
License:        GPL-2.0-only
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/nhorman/dropwatch
Source:         https://github.com/nhorman/dropwatch/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         old-readline.diff
Patch2:         https://github.com/nhorman/dropwatch/pull/83.patch
Patch3:         bfd-link-statically.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  binutils-devel
BuildRequires:  libnl3-devel
BuildRequires:  libpcap-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(libzstd)

%description
dropwatch is an interactive utility for monitoring and recording packets that
are dropped by the kernel

%prep
%setup -q
%if 0%{?suse_version} <= 1590
%patch -P 1 -p1
%endif
%patch -P 2 -p1
%patch -P 3 -p1
./autogen.sh
%configure

%build
%make_build

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man1

install -m0755 src/dropwatch %{buildroot}%{_bindir}
install -m0755 src/dwdump %{buildroot}%{_bindir}

install -m0644 doc/dropwatch.1 %{buildroot}%{_mandir}/man1
install -m0644 doc/dwdump.1 %{buildroot}%{_mandir}/man1

%files
%{_bindir}/dropwatch
%{_bindir}/dwdump
%{_mandir}/man1/dropwatch.1%{?ext_man}
%{_mandir}/man1/dwdump.1%{?ext_man}
%doc README.md
%license COPYING

%changelog
* Tue Mar 26 2024 Max Lin <mlin@suse.com>
- Add BuildRequires:  pkgconfig(libzstd)
  * libzstd-devel doesn't be added in Leap 15 build env
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- add 83.patch, bfd-link-statically.patch: fix build when
  statically linking libbfd
* Mon Apr 18 2022 Christian Boltz <suse-beta@cboltz.de>
- Update to version 1.5.4
  * Support packet drop reason reporting when included in netlink message
  * fix some minor compilation warnings/errors
  * clean up some comments about deadline support
  * convert configure.ac to use AM_PROG_LIBTOOL from outdated LT_INIT
  * Fix missing SOL_NETLINK define in glibc < 2.24
  * Fix licensing issues that didn't make sense
  * ignore ENOBUFS errors on data socket
  * adding arm64 travis ci testing
  * man page updates
  * move to libnl3 from libnl
- add old-readline.diff to revert (when building for <= 15.x) an
  upstream change that requires libreadline >= 8.0
* Wed May 20 2020 Ismail Dönmez <idonmez@suse.com>
- Install dwdump
* Wed May 20 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.5.3
  * Too many changes to list
* Fri Sep 29 2017 bpoirier@suse.com
- Update to https://github.com/nhorman/dropwatch 48c9a19
* Wed Aug 12 2015 bpoirier@suse.com
- Import from git://git.fedorahosted.org/dropwatch.git 7c33d8a
